/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.test;

import java.io.File;
import java.net.URL;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public abstract class DomainTestCase extends BasicDomainTestCase {

	private BusinessObjectFactoryTestCase factoryTestCase = new BusinessObjectFactoryTestCaseWrapper();


	/**
	 * Default constructor.
	 */
	public DomainTestCase() {
		super();
	}

	/**
	 * Named constructor.
	 * 
	 * @param name test name.
	 */
	public DomainTestCase(String name) {
		super(name);
	}

	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		if (logger.isDebugEnabled()) {
			logger.debug("setUp() - start");
		}
		factoryTestCase.setUp();
		super.setUp();
	}

	/**
	 * @see junit.framework.TestCase#tearDown()
	 */
	protected void tearDown() throws Exception {
		if (logger.isDebugEnabled()) {
			logger.debug("tearDown() - start");
		}
		super.tearDown();
		factoryTestCase.tearDown();
	}

	/**
	 * @see net.smartlab.web.test.BusinessObjectFactoryTestCase#getFactoryConfiguration()
	 */
	protected URL getFactoryConfiguration() throws Exception {
		return new File("res/smartweb.jar.hcf").toURI().toURL();
	}

	/**
	 * @see net.smartlab.web.test.BusinessObjectFactoryTestCase#getDataSetFile()
	 */
	protected abstract String getDataSetFile();


	/**
	 * Wrapper class used to avoid duplicated code: the goal achieved is to
	 * include BusinessObjectFactory initialization during Domain test cases
	 * execution as usually Domain methods call BusinessObjectFactories methods.
	 * 
	 * @author rlogiacco
	 */
	private class BusinessObjectFactoryTestCaseWrapper extends BusinessObjectFactoryTestCase {

		/**
		 * @see net.smartlab.web.test.BusinessObjectFactoryTestCase#getDataSetFile()
		 */
		protected String getDataSetFile() {
			return DomainTestCase.this.getDataSetFile();
		}

		/**
		 * @see net.smartlab.web.test.BusinessObjectFactoryTestCase#getFactoryConfiguration()
		 */
		protected URL getFactoryConfiguration() throws Exception {
			return DomainTestCase.this.getFactoryConfiguration();
		}
	}
}
